@@ -105,6 +105,9 @@ SOFTWARE.
 #define TOUCH_POINTER_EMULATED  (1 << 5)        /* touch event may be pointer emulated */
 #define TOUCH_END               (1 << 6)        /* really end this touch now */
 
+/* GetGestureEvent flags */
+#define GESTURE_CANCELLED       (1 << 0)
+
 /*int constants for pointer acceleration schemes*/
 #define PtrAccelNoOp            0
 #define PtrAccelPredictable     1
@@ -150,7 +153,9 @@ typedef struct _ValuatorClassRec *ValuatorClassPtr;
 typedef struct _ClassesRec *ClassesPtr;
 typedef struct _SpriteRec *SpritePtr;
 typedef struct _TouchClassRec *TouchClassPtr;
+typedef struct _GestureClassRec *GestureClassPtr;
 typedef struct _TouchPointInfo *TouchPointInfoPtr;
+typedef struct _GestureInfo *GestureInfoPtr;
 typedef struct _DDXTouchPointInfo *DDXTouchPointInfoPtr;
 typedef union _GrabMask GrabMask;
 
@@ -186,6 +191,12 @@ typedef Bool (*PointerAccelSchemeInitProc) (DeviceIntPtr /*dev */ ,
                                             struct _ValuatorAccelerationRec *
                                             /*protoScheme */ );
 
+typedef void (*DeviceSendEventsProc) (DeviceIntPtr /*dev */ ,
+                                      int /* event type */ ,
+                                      int /* detail, buttons or keycode */ ,
+                                      int /* flags */ ,
+                                      const ValuatorMask * /* valuators */ );
+
 typedef struct _DeviceRec {
     void *devicePrivate;
     ProcessInputProc processInputProc;  /* current */
@@ -337,6 +348,9 @@ extern _X_EXPORT Bool InitTouchClassDeviceStruct(DeviceIntPtr /*device */ ,
                                                  unsigned int /*mode */ ,
                                                  unsigned int /*numAxes */ );
 
+extern _X_EXPORT Bool InitGestureClassDeviceStruct(DeviceIntPtr device,
+                                                   unsigned int max_touches);
+
 typedef void (*BellProcPtr) (int percent,
                              DeviceIntPtr device,
                              void *ctrl,
@@ -488,6 +502,33 @@ void QueueTouchEvents(DeviceIntPtr device,
                       uint32_t ddx_touchid,
                       int flags, const ValuatorMask *mask);
 
+void InitGestureEvent(InternalEvent *ievent, DeviceIntPtr dev, CARD32 ms,
+                      int type, uint16_t num_touches, uint32_t flags,
+                      double delta_x, double delta_y,
+                      double delta_unaccel_x, double delta_unaccel_y,
+                      double scale, double delta_angle);
+
+int GetGestureEvents(InternalEvent *events, DeviceIntPtr dev,
+                     uint16_t type, uint16_t num_touches, uint32_t flags,
+                     double delta_x, double delta_y,
+                     double delta_unaccel_x,
+                     double delta_unaccel_y,
+                     double scale, double delta_angle);
+
+
+void QueueGesturePinchEvents(DeviceIntPtr dev, uint16_t type,
+                             uint16_t num_touches, uint32_t flags,
+                             double delta_x, double delta_y,
+                             double delta_unaccel_x,
+                             double delta_unaccel_y,
+                             double scale, double delta_angle);
+
+void QueueGestureSwipeEvents(DeviceIntPtr dev, uint16_t type,
+                             uint16_t num_touches, uint32_t flags,
+                             double delta_x, double delta_y,
+                             double delta_unaccel_x,
+                             double delta_unaccel_y);
+
 extern int GetTouchOwnershipEvents(InternalEvent *events,
                                    DeviceIntPtr pDev,
                                    TouchPointInfoPtr ti,
@@ -573,6 +614,12 @@ enum TouchListenerType {
     TOUCH_LISTENER_POINTER_REGULAR,
 };
 
+enum GestureListenerType {
+    GESTURE_LISTENER_GRAB,
+    GESTURE_LISTENER_NONGESTURE_GRAB,
+    GESTURE_LISTENER_REGULAR
+};
+
 extern void TouchInitDDXTouchPoint(DeviceIntPtr dev,
                                    DDXTouchPointInfoPtr ddxtouch);
 extern DDXTouchPointInfoPtr TouchBeginDDXTouch(DeviceIntPtr dev,
@@ -618,7 +665,24 @@ extern void TouchEndPhysicallyActiveTouches(DeviceIntPtr dev);
 extern void TouchEmitTouchEnd(DeviceIntPtr dev, TouchPointInfoPtr ti, int flags, XID resource);
 extern void TouchAcceptAndEnd(DeviceIntPtr dev, int touchid);
 
+extern Bool GestureInitGestureInfo(GestureInfoPtr gesture);
+extern GestureInfoPtr GestureBeginGesture(DeviceIntPtr dev, InternalEvent *ev);
+extern GestureInfoPtr GestureFindActiveByEventType(DeviceIntPtr dev, int type);
+extern void GestureEndGesture(GestureInfoPtr gi);
+extern Bool GestureResourceIsOwner(GestureInfoPtr gi, XID resource);
+extern void GestureAddListener(GestureInfoPtr gi, XID resource, int resource_type,
+                               enum GestureListenerType type,
+                               WindowPtr window, GrabPtr grab);
+extern void GestureSetupListener(DeviceIntPtr dev, GestureInfoPtr gi,
+                                 InternalEvent *ev);
+extern Bool GestureBuildSprite(DeviceIntPtr sourcedev, GestureInfoPtr gi);
+extern void GestureListenerGone(XID resource);
+extern void GestureEndActiveGestures(DeviceIntPtr dev);
+extern void GestureEmitGestureEndToOwner(DeviceIntPtr dev, GestureInfoPtr gi);
+extern void ProcessGestureEvent(InternalEvent *ev, DeviceIntPtr dev);
+
 /* misc event helpers */
+extern void CopyPartialInternalEvent(InternalEvent* dst_event, const InternalEvent* src_event);
 extern Mask GetEventMask(DeviceIntPtr dev, xEvent *ev, InputClientsPtr clients);
 extern Mask GetEventFilter(DeviceIntPtr dev, xEvent *event);
 extern Bool WindowXI2MaskIsset(DeviceIntPtr dev, WindowPtr win, xEvent *ev);
